ish  (insulter shell)
=========

Insults You Whenever You Get An Error !!!

Installation
=========

`pip install insulter`

## Usage

```
Usage: ish <commands>

```

TODO
=========

-> Add A Shell


Note
----

Its Heavily Under Work.... Report Any Bugs

Made With ♥ By SpeedX
